---
name: Bug report
about: Create a report to help us reproduce and correct the bug
title: ''
labels: 'Bug: triage'
assignees: ''

---

<!--
Before submitting a bug, please make sure the issue hasn't been already
addressed by searching through the past issues.
-->

#### Describe the bug
<!--
A clear and concise description of what the bug is.
-->

#### Steps/Code to Reproduce
<!--
Please add a minimal example (in the form of code) that reproduces the error.
Be as succinct as possible, do not depend on external data. In short, we are
going to copy-paste your code and we expect to get the same result as you.
-->

```python
Sample code to reproduce the problem
```

#### Expected Results
<!-- Example: No error is thrown. Please paste or describe the expected results.-->

#### Actual Results
<!-- Please paste or specifically describe the actual output or traceback. -->

#### Screenshots
<!-- If applicable, add screenshots to help explain your problem. -->

#### Versions
<!--
Please provide the following information:
- OS: [e.g. Windows]
- Browser (if you're reporting a bug in jupyter): [e.g. Edge, Firefox, Chrome, Safari]
- Python version: [e.g. 3.10.11]
- PyRIT version: [e.g. 0.1.0 or installed from main branch in editable mode]
- version of Python packages: please run the following snippet and paste the output:
  ```python
  import pyrit
  pyrit.show_versions()
  ```
-->

<!-- Thanks for contributing! -->
